@@ -1,4 +1,4 @@
-__version__ = '1.0.4'
+__version__ = '1.0.6'
 
 from jsw_nx.base.set import set
 from jsw_nx.base.forin import forin
@@ -7,4 +7,7 @@ from jsw_nx.base.indexof import indexof
 from jsw_nx.base.includes import includes
 from jsw_nx.base.find import find
 from jsw_nx.base.find_index import find_index
+from jsw_nx.base.map import map
+from jsw_nx.base.reduce import reduce
+from jsw_nx.base.filter import filter
 from jsw_nx.packages.days import days
